﻿PVPSound_SctQueue 				= { }
local PVPSound_NextSctUpdate 	= 0.32

-- SCTQueue
function PVPSound_AddSctToQueue(file, message, frame, unique)
	-- This function will add file to the sct queue to be shown
	-- If the file could not be found in the sound lengths table then just show it
	-- If a unique sct is already in the queue then don't add it (if the sct is already playing then the sct is still added to the queue)
	local i
	local sctfilefoundlength
	-- This is a table of soundlengths according to the selected SoundPack. UnrealTournament3 = PVPSound_UnrealTournament3Durations
	if PS_soundpackname == "UnrealTournament3" and PS_sctengine == true then
		if file ~= nil and message ~= nil and frame ~= nil then
			local sctsoundlengthtable = getglobal("PVPSound_"..PS_soundpack.."Durations")
			--[[if unique then
				for i = 1, table.getn(PVPSound_SctQueue) do
					if string.upper(PVPSound_SctQueue[i].dir) == string.upper(file) then
						-- The unique sound was already found in the queue
						return
					end
				end
			end]]--
			for i = 1, table.getn(sctsoundlengthtable) do
				if string.upper(sctsoundlengthtable[i].dir) == string.upper(file) then
					sctfilefoundlength = sctsoundlengthtable[i].duration
				end
			end
			if sctfilefoundlength then
				local scttemptable = {message = message, frame = frame, length = sctfilefoundlength}
				-- Insert the sct into the queue
				table.insert(PVPSound_SctQueue, scttemptable)
			else
				-- Not in the sound table so just show it
				PVPSound_AddToSct(message, frame)
			end
		end
	else
		-- We've got lengths for UnrealTournament3 SoundPack only. If that's not selected or soundengine is disabled then just show it
		if file ~= nil and message ~= nil and frame ~= nil then
			PVPSound_AddToSct(message, frame)
		end
	end
end

function PVPSound_AddToSct(message, frame)
	if message ~= nil and frame ~= nil then
		if PS_multikillsct == true then
			PVPSound_TriggerSct(message, frame)
		else
			if message == DoubleKill or message == MultiKill or message == MegaKill or message == UltraKill or message == MonsterKill then
			else
				PVPSound_TriggerSct(message, frame)
			end
		end
	end
end

function PVPSound_TriggerSct(message, frame)
	-- MSBT
	-- MikSBT.DisplayMessage(message, scrollArea, isSticky, colorR(0-255), colorG(0-255), colorB(0-255), fontSize, fontName, outlineIndex, texturePath)
	if MikSBT then
		MikSBT.DisplayMessage(message, frame, true, 255, 0, 0, nil, nil, nil, nil)
	 -- SCT
	 -- Message Frame -- SCT:DisplayMessage(message, color{r=0-10,g=0-10,b=0-10})
	 -- Frame1, Frame2 -- SCT:DisplayText(message, color{r=0-10,g=0-10,b=0-10}, isCrit, eventtype, frame[1,2], anitype, parent, icon)
	elseif SCT then
		if frame == "Message" or "message" or frame == "MESSAGE" or frame == "0" then
			SCT:DisplayMessage(message, {r=10,g=0,b=0})
		elseif frame == "Frame1" or frame == "Frame 1" or frame == "frame1" or frame == "frame 1" or frame == "FRAME1" or frame == "FRAME 1" or frame == "1" then
			SCT:DisplayText(PS_spree, {r=10,g=0,b=0}, true, nil, 1, nil, nil, nil)
		elseif frame == "Frame2" or frame == "Frame 2" or frame == "frame2" or frame == "frame 2" or frame == "FRAME2" or frame == "FRAME 2" or frame == "2" then
			SCT:DisplayText(PS_spree, {r=10,g=0,b=0}, true, nil, 2, nil, nil, nil)
		end
	 -- SCTD
	 -- SCT:DisplayText(message, color{r=0-10,g=0-10,b=0-10}, isCrit, eventtype, frame[3], anitype, parent, icon)
	elseif SCTD then
		if frame == "Damage" or frame == "damage" or frame == "DAMAGE" or frame == "3" then
			SCT:DisplayText(message, {r=10,g=0,b=0}, true, nil, 3, nil, nil, nil)
		end
	 -- Parrot
	 -- Parrot:ShowMessage(message, frame, sticky, colorR(0-255), colorG(0-255), colorB(0-255), font, fontsize, outline, icon)
	elseif Parrot then
		Parrot:ShowMessage(message, frame, true, 255, 0, 0, nil, nil, nil, nil)
	 -- Default Blizzard SCT
	 -- CombatText_AddMessage(message, frame, colorR(0.00-1.00), colorG(0.00-1.00), colorB(0.00-1.00))
	elseif IsAddOnLoaded("Blizzard_CombatText") then
		if not COMBAT_TEXT_SCROLL_FUNCTION then
			CombatText_UpdateDisplayedMessages()
		end
		CombatText_AddMessage(message, COMBAT_TEXT_SCROLL_FUNCTION, 1, 0, 0)
	 -- Raid Notice
	 -- RaidNotice_AddMessage(frame, message, color)
	else
		RaidNotice_AddMessage(RaidBossEmoteFrame, message, ChatTypeInfo["RAID_WARNING"])
	end
end

function PVPSound_ClearSctQueue()
	-- This function will clear all the sound queue
	-- This is used for example in the end of a battle where you no longer need to hear any more announcements
	local i
	for i = table.getn(PVPSound_SoundQueue), 1 do
		table.remove(PVPSound_SoundQueue, i)
	end
end

function PVPSound_PlayNextSct()
	-- This function will play the next sound in the queue and return how long that sound will play
	-- If there is no sound in the queue it will just return 0.32
	if (PVPSound_SctInQueue()) then
		local x
		PVPSound_AddToSct(PVPSound_SctQueue[1].message, PVPSound_SctQueue[1].frame)
		x = PVPSound_SctQueue[1].length
		table.remove(PVPSound_SctQueue,1)
		return x
	else
		return 0.32
	end
end

function PVPSound_SctInQueue()
	-- This function will return 1 if there is a sct in the queue, nil otherwise
	if table.getn(PVPSound_SctQueue) > 0 then
		return 1
	else
		return nil
	end
end

function PVPSound_UpdateSctEngine(self, elapsed)
	if PS_sctengine == true then
		self.TimeSinceLastSctUpdate = self.TimeSinceLastSctUpdate + elapsed
		while self.TimeSinceLastSctUpdate > PVPSound_NextSctUpdate do
			self.TimeSinceLastSctUpdate = self.TimeSinceLastSctUpdate - PVPSound_NextSctUpdate
			PVPSound_NextSctUpdate = PVPSound_PlayNextSct()
		end
	end
end